@@ -1,17 +1,25 @@
 package Kephra::App::EditPanel;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
+=pod
+
+=head1 NAME
+
+Kephra::App::EditPanel - visual and event settings of the editing canvas
+
+=head1 DESCRIPTION
+
+
+=cut
 use strict;
 use warnings; 
-
-# visual and event settings of the Edit Panel
-
 #
 # internal API to config und app pointer
 #
 my $ref;
 sub _ref     { $ref }
 sub _set_ref { $ref = $_[0] if is($_[0]) }
+sub _all_ref { Kephra::Document::Data::get_all_ep() }
 sub is       { 1 if ref $_[0] eq 'Wx::StyledTextCtrl'}
 sub _config  { $Kephra::config{editpanel} }
 sub _indicator_config { _config()->{indicator} }
@@ -25,7 +33,7 @@ sub gets_focus { Wx::Window::SetFocus( _ref() ) if is( _ref() ) }
 #
 # settings
 #
-sub apply_settings {
+sub apply_settings_here {
 	my $ep        = shift || _ref() || _create();
 	return unless is($ep);
 	my $conf      = _config();
@@ -34,7 +42,7 @@ sub apply_settings {
 
 	# text visuals: font whitespaces
 	load_font($ep);
-	apply_whitespace_settings($ep);
+	apply_whitespace_settings_here($ep);
 	$ep->SetWhitespaceForeground
 		( 1, &$color( $indicator->{whitespace}{color} ) );
 
@@ -48,23 +56,23 @@ sub apply_settings {
 			( 1, &$color( $indicator->{selection}{fore_color} ) );
 	}
 	$ep->SetSelBackground( 1,&$color( $indicator->{selection}{back_color}));
-	apply_EOL_settings($ep);
-	apply_LLI_settings($ep);
-	apply_caret_line_settings($ep);
-	apply_indention_guide_settings($ep);
+	apply_EOL_settings_here($ep);
+	apply_LLI_settings_here($ep);
+	apply_caret_line_settings_here($ep);
+	apply_indention_guide_settings_here($ep);
 
 	# Margins on left side
-	Kephra::App::EditPanel::Margin::apply_settings($ep);
+	Kephra::App::EditPanel::Margin::apply_settings_here($ep);
 
 	#misc: scroll width, codepage, wordchars
-	apply_autowrap_settings($ep);
+	apply_autowrap_settings_here($ep);
 
 	$ep->SetScrollWidth($conf->{scroll_width})
 		unless $conf->{scroll_width} eq 'auto';
 	#wxSTC_CP_UTF8 Wx::wxUNICODE()
 	$ep->SetCodePage(65001);#
-	set_word_chars($ep);
-	apply_bracelight_settings();
+	set_word_chars_here($ep);
+	apply_bracelight_settings_here();
 
 	# internal
 	$ep->SetLayoutCache(&Wx::wxSTC_CACHE_PAGE);
@@ -73,7 +81,7 @@ sub apply_settings {
 		? $ep->UsePopUp(1) : $ep->UsePopUp(0);
 
 	Kephra::Edit::eval_newline_sub();
-	Kephra::Edit::Bookmark::define_marker($ep);
+	Kephra::Edit::Marker::define_marker($ep);
 	connect_events($ep);
 	Kephra::EventTable::add_call ( 'editpanel.focus', 'editpanel', sub { 
 		Wx::Window::SetFocus( $ep ) unless $Kephra::temp{dialog}{active};
@@ -163,7 +171,8 @@ sub disconnect_events {
 	Wx::Event::EVT_STC_UPDATEUI($ep, -1, sub {});
 }
 
-sub set_word_chars { 
+sub set_word_chars { set_word_chars_here($_) for @{_all_ref()} }
+sub set_word_chars_here { 
 	my $ep = shift || _ref();
 	my $conf = _config();
 	if ( $conf->{word_chars} ) {
@@ -176,23 +185,20 @@ sub set_word_chars {
 #
 # line wrap
 #
-sub apply_autowrap_settings {
+sub apply_autowrap_settings { apply_autowrap_settings_here($_) for @{_all_ref()} }
+sub apply_autowrap_settings_here {
 	my $ep = shift || _ref();
 	$ep->SetWrapMode( _config()->{line_wrap} );
 	Kephra::EventTable::trigger('editpanel.autowrap');
 }
 
 sub get_autowrap_mode { _config()->{line_wrap} == &Wx::wxSTC_WRAP_WORD}
-
 sub switch_autowrap_mode {
 	_config()->{line_wrap} = get_autowrap_mode()
 		? &Wx::wxSTC_WRAP_NONE
 		: &Wx::wxSTC_WRAP_WORD;
 	apply_autowrap_settings();
 }
-         ##############
-         # indicators #
-         ##############
 #
 # bracelight
 #
@@ -209,7 +215,10 @@ sub set_bracelight_off {
 	apply_bracelight_settings()
 }#{bracelight}{mode} = 'adjacent'|'surround';
 
-sub apply_bracelight_settings {
+sub apply_bracelight_settings { 
+	apply_bracelight_settings_here($_) for @{_all_ref()}
+}
+sub apply_bracelight_settings_here {
 	my $ep = shift || _ref();
 	if (bracelight_visible()){
 		Kephra::EventTable::add_call
@@ -255,6 +264,9 @@ sub indention_guide_visible {
 	_indicator_config()->{indent_guide}{visible} 
 }
 sub apply_indention_guide_settings {
+	apply_indention_guide_settings_here($_) for @{_all_ref()}
+}
+sub apply_indention_guide_settings_here {
 	my $ep = shift || _ref();
 	$ep->SetIndentationGuides( indention_guide_visible() )
 }
@@ -268,10 +280,13 @@ sub switch_indention_guide_visibility {
 sub caret_line_visible {
 	_indicator_config()->{caret_line}{visible} 
 }
-sub apply_caret_line_settings {
+sub apply_caret_line_settings_here {
 	my $ep = shift || _ref();
 	$ep->SetCaretLineVisible( caret_line_visible() );
 }
+sub apply_caret_line_settings {
+	apply_caret_line_settings_here($_) for @{_all_ref()}
+}
 sub switch_caret_line_visibility {
 	_indicator_config()->{caret_line}{visible} ^= 1;
 	apply_caret_line_settings();
@@ -282,11 +297,10 @@ sub switch_caret_line_visibility {
 sub LLI_visible { 
 	_indicator_config()->{right_margin}{style} == &Wx::wxSTC_EDGE_LINE
 }
-sub apply_LLI_settings {
+sub apply_LLI_settings_here {
 	my $ep = shift || _ref();
 	my $config = _indicator_config()->{right_margin};
 	my $color   = \&Kephra::Config::color;
-
 	$ep->SetEdgeColour( &$color( $config->{color} ) );
 	$ep->SetEdgeColumn( $config->{position} );
 	show_LLI( $config->{style}, $ep);
@@ -296,11 +310,12 @@ sub show_LLI {
 	my $ep = shift || _ref();
 	$ep->SetEdgeMode( $style );
 }
+sub apply_LLI_settings { apply_LLI_settings_here($_) for @{_all_ref()} }
 sub switch_LLI_visibility {
 	my $style = _indicator_config()->{right_margin}{style} = LLI_visible()
 		? &Wx::wxSTC_EDGE_NONE
 		: &Wx::wxSTC_EDGE_LINE;
-	show_LLI($style);
+	apply_LLI_settings($style);
 }
 #
 # EOL = end of line marker
@@ -312,7 +327,8 @@ sub switch_EOL_visibility {
 	_config()->{indicator}{end_of_line_marker} ^= 1;
 	apply_EOL_settings();
 }
-sub apply_EOL_settings {
+sub apply_EOL_settings { apply_EOL_settings_here($_) for @{_all_ref()} }
+sub apply_EOL_settings_here {
 	my $ep = shift || _ref();
 	$ep->SetViewEOL( EOL_visible() );
 
@@ -323,10 +339,13 @@ sub apply_EOL_settings {
 sub whitespace_visible { 
 	_indicator_config()->{whitespace}{visible} 
 }
-sub apply_whitespace_settings {
+sub apply_whitespace_settings_here {
 	my $ep = shift || _ref();
 	$ep->SetViewWhiteSpace( whitespace_visible() )
 }
+sub apply_whitespace_settings { 
+	apply_whitespace_settings_here($_) for @{_all_ref()}
+}
 sub switch_whitespace_visibility {
 	my $v = _indicator_config()->{whitespace}{visible} ^= 1;
 	apply_whitespace_settings();
@@ -368,8 +387,7 @@ sub change_font {
 		$$font_config{style}  = 'normal';
 		$$font_config{style}  = 'slant' if $fontstyle == &Wx::wxSLANT;
 		$$font_config{style}  = 'italic' if $fontstyle == &Wx::wxITALIC;
-		&load_font;
-		Kephra::Document::SyntaxMode::reload();
+		Kephra::Document::SyntaxMode::reload($_) for @{Kephra::Document::Data::all_nr()};
 		Kephra::App::EditPanel::Margin::apply_line_number_width();
 	}
 }
