@@ -183,30 +183,30 @@ sub get {
 			},
 			bookmark => {
 				goto => {
-					1 => 'Kephra::Edit::Bookmark::goto_nr(1)',
-					2 => 'Kephra::Edit::Bookmark::goto_nr(2)',
-					3 => 'Kephra::Edit::Bookmark::goto_nr(3)',
-					4 => 'Kephra::Edit::Bookmark::goto_nr(4)',
-					5 => 'Kephra::Edit::Bookmark::goto_nr(5)',
-					6 => 'Kephra::Edit::Bookmark::goto_nr(6)',
-					7 => 'Kephra::Edit::Bookmark::goto_nr(7)',
-					8 => 'Kephra::Edit::Bookmark::goto_nr(8)',
-					9 => 'Kephra::Edit::Bookmark::goto_nr(9)',
-					0 => 'Kephra::Edit::Bookmark::goto_nr(0)',
+					1 => 'Kephra::Edit::Marker::goto_bookmark(1)',
+					2 => 'Kephra::Edit::Marker::goto_bookmark(2)',
+					3 => 'Kephra::Edit::Marker::goto_bookmark(3)',
+					4 => 'Kephra::Edit::Marker::goto_bookmark(4)',
+					5 => 'Kephra::Edit::Marker::goto_bookmark(5)',
+					6 => 'Kephra::Edit::Marker::goto_bookmark(6)',
+					7 => 'Kephra::Edit::Marker::goto_bookmark(7)',
+					8 => 'Kephra::Edit::Marker::goto_bookmark(8)',
+					9 => 'Kephra::Edit::Marker::goto_bookmark(9)',
+					0 => 'Kephra::Edit::Marker::goto_bookmark(0)',
 				},
 				toggle => {
-					1 => 'Kephra::Edit::Bookmark::toggle_nr(1)',
-					2 => 'Kephra::Edit::Bookmark::toggle_nr(2)',
-					3 => 'Kephra::Edit::Bookmark::toggle_nr(3)',
-					4 => 'Kephra::Edit::Bookmark::toggle_nr(4)',
-					5 => 'Kephra::Edit::Bookmark::toggle_nr(5)',
-					6 => 'Kephra::Edit::Bookmark::toggle_nr(6)',
-					7 => 'Kephra::Edit::Bookmark::toggle_nr(7)',
-					8 => 'Kephra::Edit::Bookmark::toggle_nr(8)',
-					9 => 'Kephra::Edit::Bookmark::toggle_nr(9)',
-					0 => 'Kephra::Edit::Bookmark::toggle_nr(0)',
+					1 => 'Kephra::Edit::Marker::toggle_bookmark(1)',
+					2 => 'Kephra::Edit::Marker::toggle_bookmark(2)',
+					3 => 'Kephra::Edit::Marker::toggle_bookmark(3)',
+					4 => 'Kephra::Edit::Marker::toggle_bookmark(4)',
+					5 => 'Kephra::Edit::Marker::toggle_bookmark(5)',
+					6 => 'Kephra::Edit::Marker::toggle_bookmark(6)',
+					7 => 'Kephra::Edit::Marker::toggle_bookmark(7)',
+					8 => 'Kephra::Edit::Marker::toggle_bookmark(8)',
+					9 => 'Kephra::Edit::Marker::toggle_bookmark(9)',
+					0 => 'Kephra::Edit::Marker::toggle_bookmark(0)',
 				},
-				'delete-all' => 'Kephra::Edit::Bookmark::delete_all()',
+				'delete-all' => 'Kephra::Edit::Marker::delete_all_bookmarks()',
 			},
 			tool => {
 				note => 'Kephra::App::Panel::Notepad::note()',
@@ -214,6 +214,7 @@ sub get {
 				'interpreter-run-document' => 'Kephra::App::Panel::Output::run()',
 				'interpreter-stop-document' => 'Kephra::App::Panel::Output::stop()',
 				'output-inc' => 'Kephra::App::Panel::Output::display_inc()',
+				'choose-color' => 'Kephra::Dialog::choose_color()',
 			},
 			document => {
 				'auto-indention' => 'Kephra::Document::Property::switch_autoindention()',
@@ -229,6 +230,10 @@ sub get {
 					cr => "Kephra::Document::Property::convert_EOL('cr')",
 					lf => "Kephra::Document::Property::convert_EOL('lf')",
 				},
+				encoding => {
+					'8bit' => "Kephra::Document::Property::set_codepage('8bit')",
+					'utf8' => "Kephra::Document::Property::set_codepage('utf8')",
+				},
 				move => {
 					left => 'Kephra::Document::Change::move_left()',
 					right => 'Kephra::Document::Change::move_right()',
@@ -346,10 +351,10 @@ sub get {
 						},
 					},
 					'fold-toggle' => {
-						all => 'Kephra::App::EditPanel::Margin::toggle_all()',
-						here => 'Kephra::App::EditPanel::Margin::toggle_here()',
-						recursively => 'Kephra::App::EditPanel::Margin::toggle_recursively()',
-						siblings => 'Kephra::App::EditPanel::Margin::toggle_siblings()',
+						all => 'Kephra::App::EditPanel::Fold::toggle_all()',
+						here => 'Kephra::App::EditPanel::Fold::toggle_here()',
+						recursively => 'Kephra::App::EditPanel::Fold::toggle_recursively()',
+						siblings => 'Kephra::App::EditPanel::Fold::toggle_siblings()',
 					},
 				},
 				panel => {
@@ -525,8 +530,8 @@ sub get {
 				selection => 'document.text.select',
 			},
 			'tool-interpreter' => {
-				'run-document' => 'plugin.output.run',
-				'stop-document' => 'plugin.output.run',
+				'run-document' => 'panel.output.run',
+				'stop-document' => 'panel.output.run',
 			},
 		},
 		state => {
@@ -549,16 +554,16 @@ sub get {
 			},
 			bookmark => {
 				goto => {
-					1 => 'Kephra::Edit::Bookmark::is_set(1)',
-					2 => 'Kephra::Edit::Bookmark::is_set(2)',
-					3 => 'Kephra::Edit::Bookmark::is_set(3)',
-					4 => 'Kephra::Edit::Bookmark::is_set(4)',
-					5 => 'Kephra::Edit::Bookmark::is_set(5)',
-					6 => 'Kephra::Edit::Bookmark::is_set(6)',
-					7 => 'Kephra::Edit::Bookmark::is_set(7)',
-					8 => 'Kephra::Edit::Bookmark::is_set(8)',
-					9 => 'Kephra::Edit::Bookmark::is_set(9)',
-					0 => 'Kephra::Edit::Bookmark::is_set(0)',
+					1 => 'Kephra::Edit::Marker::bookmark_is_set(1)',
+					2 => 'Kephra::Edit::Marker::bookmark_is_set(2)',
+					3 => 'Kephra::Edit::Marker::bookmark_is_set(3)',
+					4 => 'Kephra::Edit::Marker::bookmark_is_set(4)',
+					5 => 'Kephra::Edit::Marker::bookmark_is_set(5)',
+					6 => 'Kephra::Edit::Marker::bookmark_is_set(6)',
+					7 => 'Kephra::Edit::Marker::bookmark_is_set(7)',
+					8 => 'Kephra::Edit::Marker::bookmark_is_set(8)',
+					9 => 'Kephra::Edit::Marker::bookmark_is_set(9)',
+					0 => 'Kephra::Edit::Marker::bookmark_is_set(0)',
 				},
 			},
 			document => {
@@ -569,6 +574,10 @@ sub get {
 					cr => "Kephra::Document::Property::get_EOL_mode() eq 'cr'",
 					lf => "Kephra::Document::Property::get_EOL_mode() eq 'lf'",
 				},
+				encoding => {
+					'8bit' => "Kephra::Document::Property::get_codepage() eq '8bit'",
+					'utf8' => "Kephra::Document::Property::get_codepage() eq 'utf8'",
+				},
 				readonly => {
 					'as-attr' => "Kephra::Document::Property::get_readonly() eq 'protect';",
 					on => "Kephra::Document::Property::get_readonly() eq 'on';",
