@@ -18,70 +18,86 @@ sub get {
 				untitled => 'untitled'
 			},
 			menu => {
-				file => 'File',
-				file_open => 'Open',
-				file_close => 'Close',
-				file_history => 'Recently Closed',
-				file_save => 'Save',
-				file_session => 'Session',
-				file_insert_templates => 'Templates',
-				edit => 'Edit',
-				edit_changes => 'History',
-				current_line => 'Line',
-				selection => 'Selection',
-				selection_format => 'Format',
-				selection_comment => 'Comment',
-				selection_convert => 'Convert',
-				search => 'Search',
-				search_attributes => 'Attributes',
-				find_functions => 'Find Functions',
-				replace_functions => 'Replace Functions',
-				bookmark_goto => 'Goto Bookmark',
-				bookmark_toggle => 'Toggle Bookmark',
-				tools => 'Tools',
-				document => 'Document',
-				document_change => 'Change',
-				document_convert => 'Convert',
-				document_syntaxmode => 'Syntaxmode',
-				'document_syntaxmode_A-M' => 'A - M',
-				'document_syntaxmode_N-Z' => 'N - Z',
-				document_syntaxmode_compiled => 'Compiled',
-				document_syntaxmode_interpreted => 'Interpreted',
-				document_syntaxmode_data_structure => 'Data Structure',
-				document_syntaxmode_document => 'Documents',
-				document_syntaxmode_web => 'Webprogramming',
-				document_syntaxmode_special => 'Special',
-				document_tab_width => 'Tab Width',
-				document_lineendchar => 'Lineendchars',
-				document_readonly => 'Write Protection',
-				view => 'View',
-				view_bars => 'App Bars',
-				view_panel => 'Panel',
-				view_contextmenu => 'Context Menus',
-				view_editpanel_contexmenu => 'Edit Panel',
-				view_textmargin => 'Text Margin',
-                view_text_fold => 'Folding',
-				config => 'Config',
-				config_app_lang => 'Language',
-				config_global => 'Global Config File',
-				config_interface => 'User Interface',
-				config_localisation => 'Localisation',
-				'config_syntaxmode_A-M' => 'Syntaxmodes A - M',
-				'config_syntaxmode_N-Z' => 'Syntaxmodes N - Z',
-				help => 'Help'
+				label => {
+					file => 'File',
+					file_open => 'Open',
+					file_close => 'Close',
+					file_history => 'Recently Closed',
+					file_save => 'Save',
+					file_session => 'Session',
+					file_insert_templates => 'Templates',
+					edit => 'Edit',
+					edit_changes => 'History',
+					current_line => 'Line',
+					selection => 'Selection',
+					selection_format => 'Format',
+					selection_comment => 'Comment',
+					selection_convert => 'Convert',
+					search => 'Search',
+					search_attributes => 'Attributes',
+					find_functions => 'Find Functions',
+					replace_functions => 'Replace Functions',
+					bookmark_goto => 'Goto Bookmark',
+					bookmark_toggle => 'Toggle Bookmark',
+					tools => 'Tools',
+					document => 'Document',
+					document_change => 'Change',
+					document_convert => 'Convert',
+					document_syntaxmode => 'Syntaxmode',
+					'document_syntaxmode_A-M' => 'A - M',
+					'document_syntaxmode_N-Z' => 'N - Z',
+					document_syntaxmode_compiled => 'Compiled',
+					document_syntaxmode_interpreted => 'Interpreted',
+					document_syntaxmode_data_structure => 'Data Structure',
+					document_syntaxmode_document => 'Documents',
+					document_syntaxmode_web => 'Webprogramming',
+					document_syntaxmode_special => 'Special',
+					document_encoding => 'Encoding',
+					document_tab_width => 'Tab Width',
+					document_lineendchar => 'Lineendchars',
+					document_readonly => 'Write Protection',
+					view => 'View',
+					view_bars => 'App Bars',
+					view_panel => 'Panel',
+					view_contextmenu => 'Context Menus',
+					view_editpanel_contexmenu => 'Edit Panel',
+					view_textmargin => 'Text Margin',
+					view_text_fold => 'Folding',
+					config => 'Config',
+					config_app_lang => 'Language',
+					config_global => 'Global Config File',
+					config_interface => 'User Interface',
+					config_localisation => 'Localisation',
+					'config_syntaxmode_A-M' => 'Syntaxmodes A - M',
+					'config_syntaxmode_N-Z' => 'Syntaxmodes N - Z',
+					help => 'Help'
+				},
+				help => {
+				},
 			},
 			status => {
-				chars => 'Chars',
-				column => 'Column',
-				line => 'Line',
-				lines => 'Lines',
-				selection => 'Selection',
-				soft_tabs => 'soft tabs',
-				hard_tabs => 'hard tabs',
-				now_is => 'Now is',
-				last_change => 'Last change',
-				date => 'Date',
-				time => 'Time',
+				label => {
+					chars => 'Chars',
+					column => 'Column',
+					line => 'Line',
+					lines => 'Lines',
+					selection => 'Selection',
+					soft_tabs => 'soft tabs',
+					hard_tabs => 'hard tabs',
+					now_is => 'Now is',
+					last_change => 'Last change',
+					date => 'Date',
+					time => 'Time',
+				},
+				help => {
+					cursor => 'caret (text cursor) position',
+					selection => 'selection size or position in percentage',
+					syntaxmode => 'changes the current set syntaxmode',
+					codepage => 'encoding settings',
+					tab => 'change the use of tabs and spaces',
+					EOL => 'view or change the end of line character',
+					message => 'info field, can also show infos about the current file',
+				},
 			},
 		},
 		commandlist => {
@@ -284,6 +300,7 @@ sub get {
 					'interpreter-run-document' => 'Run',
 					'interpreter-stop-document' => 'Stop',
 					'output-inc' => '@INC',
+					'choose-color' => 'Color Picker',
 				},
 				document => {
 					'auto-indention' => 'Autoindention',
@@ -299,6 +316,10 @@ sub get {
 						prev => 'Previous Tab',
 						'next' => 'Next Tab',
 					},
+					encoding => {
+						'8bit' => '8 Bit',
+						'utf8' => 'UTF-8',
+					},
 					move => {
 						left => 'Move Left',
 						right => 'Move Right',
@@ -712,6 +733,7 @@ sub get {
 					'interpreter-run-document' => 'run current programm and show result in output panel',
 					'interpreter-stop-document' => 'stop the current running output panel process',
 					'output-inc' => 'display the include pathes in the ouput panel',
+					'choose-color' => 'display text selection as color and choose a new from a rainbow',
 				},
 				document => {
 					'auto-indention' => 'indents new line like previous when Enter pressed',
@@ -727,6 +749,10 @@ sub get {
 						prev => 'changes the current document one tab to the left',
 						next => 'changes the current document one tab to the right',
 					},
+					encoding => {
+						'8bit' => 'converts document encoding into 8 Bit',
+						'utf8' => 'converts document encoding into UTF-8',
+					},
 					move => {
 						left => 'move current document in the tabbar one pos to the left',
 						right => 'move current document in the tabbar one pos to the right',
@@ -952,7 +978,7 @@ sub get {
 				title => 'Configuration Dialog',
 				panel => {
 					general => 'General',
-                    main_window => 'Main Window',
+					main_window => 'Main Window',
 					edit => 'Edit Panel',
 					files => 'Files',
 				},
